*:*********************************************************************
*:
*: Procedure file: KPROC.PRG
*:
*:         System: Advanced Computers xBase Tool Library
*:         Author: Kevin Price
*:      Copyright (c) 1992, Advanced Software
*:  Last modified: 07/24/92     15:27
*:
*:  Procs & Fncts: 
*:               : NUMSTR
*:               : YN
*:               : FYI
*:               : GUAGE
*:               : FDATECOMP
*:
*:      Documented 07/24/92 at 17:02               FoxDoc  version 2.10b
*:*********************************************************************

*** Here are a few of my favorite things:
*** Feel free to use or abuse this code in any way you see fit.
*** If you like it or it helps, let me know.
***
*** GUAGE is my favorite thermometer routine because it is accurate to
*** one percent, it can be used for increasing or decreasing percentages,
*** and it is released by simply calling GUAGE with no parameters.
***
*** EXAMPLES:
***
*** NumStr(1234, 6)
*** Returns "001234"
***
*** YN("Are You Sure?", .T.) 
*** Pops up a window that asks a yes/no question
*** Returns .T./.F. Defaults to .T.
***
*** YN("Are You Sure?", .F.) 
*** Pops up a window that asks a yes/no question
*** Returns .T./.F. Defaults to .F.
***
*** YN("Hit Return") 
*** Pops up a window that waits for <Enter>
*** Always Returns .T.
***
*** Do FYI with "For Your Information!"
*** Displays message in window
***
*** Do FYI 
*** Releases Message Window
***
*** Do Guage with 15, "Gas Guage"
*** Pop up a window and display 15% graphically
***
*** Do Guage with 25
*** Adjust guage Bar to 25%
***
*** Do Guage 
*** Release the Guage window
***
*** Notice that calling FYI or Guage with no prarmeters releases the
*** FYI or Guage window.
***
*** FDateComp("File1", "File2")
*** Returns 0 ... File1 older or same age as File2
***         1 ... File1 newer than File2
***         2 ... Error reading one or more files
***
*** This is useful when you want to se if an extract file is older than
*** your data file.  



*!*********************************************************************
*!
*!      Procedure: NUMSTR
*!
*!*********************************************************************
FUNCTION NumStr
PARAMETER M.NumIn, M.StrLen

*** Function returns String version of NumIn with leading zeros
*** to StrLen length.

PRIVATE M.NumIn, M.StrLen

RETURN RIGHT("0000000000" + LTRIM(STR(M.NumIn, M.StrLen)), M.StrLen)


*!*********************************************************************
*!
*!      Procedure: YN
*!
*!      Called by: ERROR_FIX          (procedure in PROC1.PRG)
*!
*!*********************************************************************
FUNCTION YN
PARAMETER M.YNText, M.YNA

PRIVATE M.YNText, M.YNA, M.YNTLines, M.WVSize, M.YND, M.PicStr

*** Function displays a Requistor/Alert and returns Logical Response

*** m.YNText : Message to Display
*** m.YNA    : Default answer to Question (.T. / .F.)

*** If you send a default answer (YNA), you get a Yes/No Requistor
*** Returns: .T. (Yes) or .F. (NO)

*** If you only send a message (YNText), you get a Message Requistor
*** Always returns .T.

*** Modified 6-12-92 KDP
*** Added escape and default selection to yes/no get
*** Defined private variables (Used to PRIVATE ALL)

*** Modified 7-22-92 KDP
*** Read is now MODAL

SET MEMOWIDTH TO 25
M.YNTLines  = MEMLINES(M.YNText)  &&& Number of lines in YNText

IF M.YNTLines > 11
  M.YNTLines = 11
ENDIF
M.WVSize    = M.YNTLines + 4  &&& Window Vertical Size

DEFINE WINDOW Yesno ;
  FROM INT((SROW() - M.WVSize) / 2), ;
  INT((SCOL() - 29) / 2) ;
  TO INT((SROW() - M.WVSize) / 2) + M.WVSize - 1, ;
  INT((SCOL() - 29) / 2) + 28 ;
  FLOAT ;
  NOCLOSE ;
  SHADOW ;
  DOUBLE ;
  COLOR SCHEME 5

ACTIVATE WINDOW Yesno TOP

@  0, 1 SAY LEFT(M.YNText, 255) ;
  SIZE M.YNTLines, 25 ;
  PICTURE "@TI"

@ M.YNTLines, 0 SAY ""

IF PARAMETERS() = 2   &&& This is a Yes/No Requister
  *** Set Default Pushbutton ***
  IF M.YNA
    YND = 1
    M.PicStr = "@*HT \!\?\<Yes;\<No"
  ELSE
    M.YND = 2
    M.PicStr = "@*HT \<Yes;\!\?\<No"
  ENDIF
  
  @ M.YNTLines + 1, 6 GET M.YND PICTURE M.PicStr SIZE 1, 5, 5
  
ELSE                  &&& This is a Message Requister
  M.YND = 1
  @ YNTLines + 1, 11 GET M.YND PICTURE "@*HT \!OK" SIZE 1, 6, 1
  
ENDIF

READ CYCLE OBJECT M.YND MODAL

RELEASE WINDOW Yesno

IF M.YND = 1
  M.YNA = .T.
ELSE
  M.YNA = .F.
ENDIF

RETURN M.YNA   &&& YN &&&


*!*********************************************************************
*!
*!      Procedure: FYI
*!
*!*********************************************************************
PROCEDURE FYI
PARAMETER M.FYIText, M.Blink

PRIVATE M.FYIText, M.TLines, M.WVSize, M.Blink

*** Procedure displays a message in a window

*** FYIText : (c) Message to display
*** Blink   : (l) Does message blink?
***
*** Calling with FYIText opens window and displays message, leaving window
*** open.
***
*** Calling with no parameter closes window.

*** Modified:
*** 6-23-92 KDP
*** Added m.Blink parameter

*** 7-7-92 KDP
*** Removed test for existing window.  Window is now always redefined.
*** This allows the window to adjust to the message size every time it
*** is called.
*** Defined list of Private variables. Used to Private ALL.

IF PARAMETERS() = 0  &&& Kill FYI
  
  IF WEXIST("FYI")
    RELEASE WINDOW FYI
  ENDIF
  
ELSE
  
  SET MEMOWIDTH TO 45
  M.TLines = MEMLINES(M.FYIText)  &&& Number of lines in MessText
  
  IF M.TLines > 6
    M.TLines = 6
  ENDIF
  
  M.WVSize = M.TLines + 2  &&& Window Vertical Size
  
  DEFINE WINDOW FYI ;
    TITLE "F.Y.I." ;
    FROM INT((SROW() - M.WVSize) / 2), ;
    INT((SCOL() - 49) / 2) ;
    TO INT((SROW() - M.WVSize) / 2) + M.WVSize - 1, ;
    INT((SCOL() - 49) / 2) + 48 ;
    FLOAT ;
    NOCLOSE ;
    SHADOW ;
    DOUBLE ;
    COLOR SCHEME 5
  
  ACTIVATE WINDOW FYI TOP
  CLEAR
  
  IF M.Blink           &&& Blinking Text
    M.BColor = STRTRAN(SCHEME(5, 1), "/", "*/")
  ELSE
    M.BColor = SCHEME(5, 1)
  ENDIF
  
  @ 0,1 SAY LEFT(M.FYIText, 255) ;
    SIZE M.TLines, 45 ;
    PICTURE "@TI" ;
    COLOR (M.BColor)
  
ENDIF

RETURN   &&& FYI &&&


*!*********************************************************************
*!
*!      Procedure: GUAGE
*!
*!*********************************************************************
PROCEDURE GUAGE
PARAMETER M.Pct, M.Msg

PRIVATE M.Pct, M.Msg, M.G0, M.G1, M.G2, M.GNum, M.GStr1, M.GLen

*** Show a percentage between 0 and 100 graphically      ***
*** Call without parameters or set PCT > 100 to shut     ***
*** down the guage.                                      ***
*** MSG is displayed centered above the guage            ***

*** Color Scheme 16's @ Say color defines the color of the guage bar
*** (Yellow on Purple)

*** Modified:
*** 6-23-92 KDP
*** Calling with no parameters now closes Guage, calling with m.PCT > 100
*** still closes guage as usual.
*** Removed Return statement from middle of procedure. Only one return
*** remains.

*** Create the Guage window if it doesn't exist
IF .NOT. WEXIST("Guage")
  
  DEFINE WINDOW Guage ;
    FROM INT((SROW() - 9) / 2), ;
    INT((SCOL() - 54) / 2) ;
    TO INT((SROW() - 9) / 2) + 8, ;
    INT((SCOL() - 54) / 2) + 53 ;
    DOUBLE ;
    SHADOW ;
    COLOR SCHEME 5
  
  ACTIVATE WINDOW Guage TOP
  CLEAR
  @ 3, 0 SAY "0           25          50           75          100"
  @ 4, 0 SAY "ķ"
  @ 5, 0 SAY "                                               "
  @ 6, 0 SAY "Ľ"
  
ENDIF

*** Activate the Guage window if it is hidden ***
IF .NOT. WVISIBLE("Guage")
  ACTIVATE WINDOW Guage
ENDIF

IF (PARAMETERS() = 0) .OR. ((TYPE("m.Pct") = "N") .AND. (M.Pct > 100))
  
  *** Close the Guage window ***
  RELEASE WINDOW Guage
  
ELSE
  
  *** Draw the guage bar ***
  
  *** Define Variables ***
  M.G0 = "                                               "
  M.G1 = ""
  M.G2 = ""
  
  *** Build gas guage string ***
  M.GNum   = ABS(M.Pct / 2)
  M.GStr1  = REPLICATE(M.G2, M.GNum)
  
  *** Add on a sliver ***
  IF INT(M.Pct % 2) # 0
    M.GStr1 = M.GStr1 + M.G1
  ENDIF
  
  *** Build empty part of the gas guage string ***
  M.GLen  = LEN(M.GStr1)
  M.GStr2 = RIGHT(M.G0, 50 - M.GLen)
  
  *** Print the gas level ***
  @ 5, 1 SAY M.GStr1 COLOR SCHEME 16
  @ 5,M.GLen + 1 SAY M.GStr2
  
  *** Print the status message ***
  IF PARAMETERS() = 2
    @ 0, 1 SAY  M.Msg PICTURE "@I" SIZE 2, 51
  ENDIF
  
ENDIF

RETURN  &&& Guage &&&


*!*********************************************************************
*!
*!      Procedure: FDATECOMP
*!
*!          Calls: F1()               (function  in ?)
*!               : F2()               (function  in ?)
*!
*!*********************************************************************
FUNCTION FDateComp
PARAMETER M.File1, M.File2

PRIVATE M.File1, M.File2, F1, F2, M.FC1, M.FC2, M.Newer

*** Compare file change dates and times of File1 and File2
***
*** Returns:
*** 0 ... File1 older or same age as File2
*** 1 ... File1 newer than File2
*** 2 ... Error reading one or more files
***

M.Newer = 2

IF ADIR(F1, M.File1) = 1  &&& One and only one file found!
  
  IF ADIR(F2, M.File2) = 1  &&& One and only one file found!
    
    M.FC1 = (DTOC(F1(3), 1) + F1(4)) &&& Bulid date + time string for comp.
    M.FC2 = (DTOC(F2(3), 1) + F2(4))
    
    IF M.FC1 > M.FC2
      M.Newer = 1
    ELSE
      M.Newer = 0
    ENDIF
    
  ENDIF
  
ENDIF
RETURN M.Newer   &&& FDateComp &&&


